@@ -4,7 +4,16 @@ import unicodedata
 from os import listdir
 from os.path import isfile, join
 
-import PyPDF2
+try:
+
+    import PyPDF2
+
+except BaseException as e:
+    def install(package):
+        subprocess.check_call([sys.executable, "-m", "pip", "install", package])
+
+
+    install("PyPDF2")
 import nltk
 import numpy
 import pandas as pd
